@@ -1,4 +1,4 @@
 from .interaction import *
 from .slash_interaction import *
-from .button_interaction import *
+from .message_interaction import *
 from .message_components import *
